﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using AR.SystemController;

namespace SC2000_Example
{
    public partial class Form1 : Form
    {
        SC2000 sc;
        public Form1()
        {
            InitializeComponent();

            // Set the datasource of the config combobox to the enumerator containing all of the configuration names
            cbConfig.DataSource = Enum.GetValues(typeof(SC2000.ConfigName));

            // Create a new instance of an SC2000 object
            sc = new SC2000();
        }

        private void btnInitialize_Click(object sender, EventArgs e)
        {
            // Try to close a previous session before opening a new one
            try
            {
                sc.Close();
            }
            catch (NullReferenceException) { }

            try
            {
                Cursor.Current = Cursors.WaitCursor;

                // Initialize a new session
                if (sc.Initialize(txtAddress.Text) == 0)
                {
                    btnSetAll.Enabled = true;
                    btnSaveConfig.Enabled = true;
                    btnLoadConfig.Enabled = true;

                    // Query the ID string
                    txtIDN.Text = sc.QueryID();

                    // Query the current state of the switches
                    numSw1.Value = sc.QuerySwitch(1);
                    numSw2.Value = sc.QuerySwitch(2);
                    numSw3.Value = sc.QuerySwitch(3);
                    numSw4.Value = sc.QuerySwitch(4);

                    // Query the current state of the open drain outputs
                    chkOD1.Checked = sc.QueryOpenDrain(1);
                    chkOD2.Checked = sc.QueryOpenDrain(2);
                    chkOD3.Checked = sc.QueryOpenDrain(3);
                    chkOD4.Checked = sc.QueryOpenDrain(4);

                    // Query the current state of the TTL outputs
                    chkTTL1.Checked = sc.QueryTTL(1);
                    chkTTL2.Checked = sc.QueryTTL(2);
                    chkTTL3.Checked = sc.QueryTTL(3);
                    chkTTL4.Checked = sc.QueryTTL(4);
                }
            }
            catch (Ivi.Visa.NativeVisaException)
            {
                // Disable buttons when there is an error initializing
                btnSetAll.Enabled = false;
                btnSaveConfig.Enabled = false;
                btnLoadConfig.Enabled = false;
                txtIDN.Text = "";
                MessageBox.Show("Error initializing. Check the VISA address and try again.");
            }
            finally
            {
                Cursor.Current = Cursors.Default;
            }
        }

        private void btnSetAll_Click(object sender, EventArgs e)
        {
            // Create 2D arrays of the form {switch/open drain/TTL, position} in each row
            int[,] switches = {
                {1, (int)numSw1.Value },
                {2, (int)numSw2.Value },
                {3, (int)numSw3.Value },
                {4, (int)numSw4.Value }
            };
            int[,] openDrains = {
                {1, chkOD1.Checked ? 1 : 0 },
                {2, chkOD2.Checked ? 1 : 0 },
                {3, chkOD3.Checked ? 1 : 0 },
                {4, chkOD4.Checked ? 1 : 0 }
            };
            int[,] TTLs = {
                {1, chkTTL1.Checked ? 1 : 0 },
                {2, chkTTL2.Checked ? 1 : 0 },
                {3, chkTTL3.Checked ? 1 : 0 },
                {4, chkTTL4.Checked ? 1 : 0 }
            };

            Cursor.Current = Cursors.WaitCursor;

            // Use the functions that set multiple switches and outputs in a single command.
            // These are faster since the safety switch only needs to be set once during each command.
            sc.SetSwitches(switches);
            sc.SetOpenDrains(openDrains);
            sc.SetTTLs(TTLs);

            Cursor.Current = Cursors.Default;
        }

        private void btnSaveConfig_Click(object sender, EventArgs e)
        {
            // Save the configuration using the enumerator from the combobox
            sc.SaveConfiguration((SC2000.ConfigName)cbConfig.SelectedItem);
        }

        private void btnLoadConfig_Click(object sender, EventArgs e)
        {
            Cursor.Current = Cursors.WaitCursor;

            // Load a configuration using the enumerator from the combobox
            sc.LoadConfiguration((SC2000.ConfigName)cbConfig.SelectedItem);

            Cursor.Current = Cursors.Default;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            try
            {
                // Set the SC2000 back to local mode before closing
                sc.LocalMode();
                sc.Close();
            }
            catch { }
        }

    }
}
