
// Field Monitor ExampleDlg.cpp : implementation file
//

#include "stdafx.h"
#include "Field Monitor Example.h"
#include "Field Monitor ExampleDlg.h"
#include "afxdialogex.h"
#include <string>

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

using namespace std;

// CFieldMonitorExampleDlg dialog



CFieldMonitorExampleDlg::CFieldMonitorExampleDlg(CWnd* pParent /*=NULL*/)
	: CDialogEx(IDD_FIELDMONITOREXAMPLE_DIALOG, pParent)
	, numChannel(0)
	, numFrequency(0)
	, chkX(FALSE)
	, chkY(FALSE)
	, chkZ(FALSE)
	, dataX(0)
	, dataY(0)
	, dataZ(0)
	, dataC(0)
	, chkStatusOK(FALSE)
{
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CFieldMonitorExampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialogEx::DoDataExchange(pDX);
	DDX_Control(pDX, IDC_ADDRESS, txtAddress);
	DDX_Text(pDX, IDC_CHANNEL, numChannel);
	DDV_MinMaxInt(pDX, numChannel, 1, 4);
	DDX_Text(pDX, IDC_EDIT3, numFrequency);
	DDX_Check(pDX, IDC_CHECKX, chkX);
	DDX_Check(pDX, IDC_CHECKY, chkY);
	DDX_Check(pDX, IDC_CHECKZ, chkZ);
	DDX_Control(pDX, IDC_MODEL, txtModel);
	DDX_Control(pDX, IDC_SERIAL, txtSerial);
	DDX_Control(pDX, IDC_FIRMWARE, txtFirmware);
	DDX_Text(pDX, IDC_DATAX, dataX);
	DDX_Text(pDX, IDC_DATAY, dataY);
	DDX_Text(pDX, IDC_DATAZ, dataZ);
	DDX_Text(pDX, IDC_DATAC, dataC);
	DDX_Check(pDX, IDC_CHECKSTATUSOK, chkStatusOK);
	DDX_Control(pDX, IDC_READ, btnRead);
}

BEGIN_MESSAGE_MAP(CFieldMonitorExampleDlg, CDialogEx)
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_INITIALIZE, &CFieldMonitorExampleDlg::OnBnClickedInitialize)
	ON_BN_CLICKED(IDC_READ, &CFieldMonitorExampleDlg::OnBnClickedRead)
	ON_WM_CLOSE()
END_MESSAGE_MAP()


// CFieldMonitorExampleDlg message handlers

BOOL CFieldMonitorExampleDlg::OnInitDialog()
{
	CDialogEx::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon

	// Initialize the address to a valid GPIB resource
	txtAddress.SetWindowText(TEXT("GPIB::5::INSTR"));

	numChannel = 1;
	numFrequency = 80e6;
	chkX = true;
	chkY = true;
	chkZ = true;

	UpdateData(false);

	btnRead.EnableWindow(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CFieldMonitorExampleDlg::OnPaint()
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialogEx::OnPaint();
	}
}

// The system calls this function to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CFieldMonitorExampleDlg::OnQueryDragIcon()
{
	return static_cast<HCURSOR>(m_hIcon);
}



void CFieldMonitorExampleDlg::OnBnClickedInitialize()
{
	CString address;
	txtAddress.GetWindowText(address);

	UpdateData(true);

	fm.Close();

	// Initialize a new session
	if (fm.Initialize(string(address), false) == 0)
	{
		// Set the display to XYZ
		fm.ConfigureDisplayMode(XYZ);

		// Enable the selected channel
		fm.ConfigureChannelState(numChannel, true);

		// Enable frequency correction and set the frequency
		fm.ConfigureFrequencyCorrection(true);
		fm.SetFrequency(numFrequency);

		// Configure the axes used for composite calculation
		fm.ConfigureAxes(numChannel, chkX, chkY, chkZ);

		// Query information about the attached probe
		ProbeID probe = fm.QueryProbeStatus(numChannel);
		txtModel.SetWindowText(probe.model.c_str());
		txtSerial.SetWindowText(probe.serial.c_str());
		txtFirmware.SetWindowText(probe.firmware.c_str());

		// Enable the read button
		btnRead.EnableWindow(TRUE);
	}
}


void CFieldMonitorExampleDlg::OnBnClickedRead()
{
	// Take a reading from the probe
	ProbeData data = fm.ReadData(numChannel);

	// Fill data from the returned ProbeData struct
	dataX = data.x;
	dataY = data.y;
	dataZ = data.z;
	dataC = data.c;
	chkStatusOK = data.statusOK;

	UpdateData(false);
}


void CFieldMonitorExampleDlg::OnClose()
{
	// Close the VISA session
	fm.Close();

	CDialogEx::OnClose();
}
